@font-face { font-family:Inter; font-style:normal; font-weight:400; font-display:swap; src:url(./font/Inter-Regular.ttf) format("truetype"); }
@font-face { font-family:Inter; font-style:italic; font-weight:400; font-display:swap; src:url(./font/Inter-Italic.ttf) format("truetype"); }
@font-face { font-family:Inter; font-style:normal; font-weight:700; font-display:swap; src:url(./font/Inter-Bold.ttf) format("truetype"); }
@font-face { font-family:Inter; font-style:italic; font-weight:700; font-display:swap; src:url(./font/Inter-BoldItalic.ttf) format("truetype"); }